/*
 * SPDX-License-Identifier: BSD-3-Clause
 *
 * Copyright (c) 2010-2020, The Regents of the University of California
 * (Regents).  All Rights Reserved.
 */

#ifndef __SYS_HTIF_H__
#define __SYS_HTIF_H__

#include <sbi/sbi_types.h>

int htif_serial_init(void);

int htif_system_reset_init(void);

#endif
